@@ -1,8 +1,6 @@
 import math
 import numpy as np
 
-def rgb2gray(rgb):
-    return np.dot(rgb[...,:3], [0.2989, 0.5870, 0.1140])
 
 def sample_sphere_2D(number_of_samples):
     sphere_points = np.zeros((number_of_samples, 2))
